==> byways-1.10.9.tgz: package/contents/byway/2070.md <==
---
template: byway.jade
id: "2070"
name: Longleaf Trail Scenic Byway
distance: "17"
duration: Allow at least half an hour.
description: "Recognized as one of the most scenic drives in Louisiana, many vistas along the 17-mile drive offer views of mesas, buttes, and sandstone outcroppings."
contact: "**Kisatchie Ranger District**  \r\n 318-352-2568  \r\n\r\n"
path: "qie_EfxxwP[kB]qE?iE[gPMoC{@mK?sAPkA^mAdCmFbDgGzBsC~B{Db@}@lC}HfD_FtD{Jf@y@dAsExAsJTuFR}@hAcJd@kE^oGF{EEqCsBuL@sBrAcOJaG`AaUZmDtAaHDmCAuLKsBg@gC_H}Vi@mCKeBCaDN_ECeBQ{@}C_IYgAy@mN?mEP{FU{FBwChAuI~BaKJeC}E{nASaBuEwWiAmFgGuOaE{LcEaKQ{@KcBx@uQh@{D|AaIGqBe@cAsL{Me@iAKoAPsBnEaJt@mCvBgQ?eBMaAs@qAoGgEqByCcOoc@eAyB_KyMiOwR}JuLaP}SqAwBiP_^iBaDaHeI}BuC_McVw@mAcCeCuEyDw@iAi@yA{AwLcCsYHyC^_Bt@oAvYsUjAm@tE{@lAe@jLmIxBs@`SyD|`@oMvAK~BR`EjBlExAzBl@~FdAlMzArBArAYf@YhAw@\\a@hA_Ct@gCj@eDTyBf@aIl@mCVk@r@{@vEgDt@y@x@eB`CuIp@qAnBwAtJiCrBeArAaA|KsL|@eCVcC?y@JcB\\s@jCaDjBaFv@cAjCoBlAsBx@sCbPup@rCyIzAsD~AsBrByAfT}L`DyBfP{Ov@eAt@uBd@kFh@{Ad@o@fH}FzBaGVsB@wAg@oG@}@ZoAlBqCpIoKjEeHV{@FyAM_A}C_Hm@{BKeBJ{DOsAa@cAuBaDUy@G{@F_Bl@mDxEaOd@mBFyAGy@qHcXuGyY{AwF"
websites: 
  - url: "http://www.fs.usda.gov/kisatchie/"
    name: Kisatchie National Forest
  - url: "http://gorp.away.com/gorp/activity/byway/la_longl.htm"
    name: "Longleaf Trail Scenic Byway - Lousiana Scenic Drives"
designations: 
  - National Forest Scenic Byway
  - Louisiana State Scenic Byway
states: 
  - LA
ll: 
  - -93.193153
  - 31.489691000000107
bounds: 
  - - -93.193153
    - 31.45694000000009
  - - -92.96180699999996
    - 31.516010000000108

---

Located south of the Natchitoches, the 17-mile Longleaf Trail Scenic Byway guides motorists through the most unique scenery in the Kisatchie National Forest, offering natural beauty as well as direct and indirect access to several popular recreation spots in the Kisatchie Hills area. 

The byway traverses the Kisatchie Ranger District, the most scenic and enticing area within the 600,000 acre Kisatchie National Forest.  It also crosses the Kisatchie Bayou, a scenic stream flowing through the district from south to north into Old River. Backpackers and hikers can explore the 8,700-acre Kisatchie Hills Wilderness and its Backbone Trail. In addition, horse riders will enjoy the Caroline Dormon Hiking and Equestrian Trail. Deer, Turkey, songbirds and other wildlife can be also viewed throughout the district.

Some "must see" sites are Kisatchie Bayou Recreation Area and Longleaf Vista, where hikers and picnickers enjoy spectacular scenery. An abundance of wildflowers, scenic views, thriving hardwood and pine forests, historic points, and unusual rock formations inspire visitors to return often.

==> byways-2.3.2.tgz: package/contents/byway/2070.md <==
---
id: "2070"
name: Longleaf Trail Scenic Byway
distance: "17"
duration: Allow at least half an hour.
description: "Recognized as one of the most scenic drives in Louisiana, many vistas along the 17-mile drive offer views of mesas, buttes, and sandstone outcroppings."
contact: "**Kisatchie Ranger District**  \r\n 318-352-2568  \r\n\r\n"
path: "qie_EfxxwP[kB]qE?iE[gPMoC{@mK?sAPkA^mAdCmFbDgGzBsC~B{Db@}@lC}HfD_FtD{Jf@y@dAsExAsJTuFR}@hAcJd@kE^oGF{EEqCsBuL@sBrAcOJaG`AaUZmDtAaHDmCAuLKsBg@gC_H}Vi@mCKeBCaDN_ECeBQ{@}C_IYgAy@mN?mEP{FU{FBwChAuI~BaKJeC}E{nASaBuEwWiAmFgGuOaE{LcEaKQ{@KcBx@uQh@{D|AaIGqBe@cAsL{Me@iAKoAPsBnEaJt@mCvBgQ?eBMaAs@qAoGgEqByCcOoc@eAyB_KyMiOwR}JuLaP}SqAwBiP_^iBaDaHeI}BuC_McVw@mAcCeCuEyDw@iAi@yA{AwLcCsYHyC^_Bt@oAvYsUjAm@tE{@lAe@jLmIxBs@`SyD|`@oMvAK~BR`EjBlExAzBl@~FdAlMzArBArAYf@YhAw@\\a@hA_Ct@gCj@eDTyBf@aIl@mCVk@r@{@vEgDt@y@x@eB`CuIp@qAnBwAtJiCrBeArAaA|KsL|@eCVcC?y@JcB\\s@jCaDjBaFv@cAjCoBlAsBx@sCbPup@rCyIzAsD~AsBrByAfT}L`DyBfP{Ov@eAt@uBd@kFh@{Ad@o@fH}FzBaGVsB@wAg@oG@}@ZoAlBqCpIoKjEeHV{@FyAM_A}C_Hm@{BKeBJ{DOsAa@cAuBaDUy@G{@F_Bl@mDxEaOd@mBFyAGy@qHcXuGyY{AwF"
websites:
  - url: "http://www.fs.usda.gov/kisatchie/"
    name: Kisatchie National Forest
  - url: "https://en.wikipedia.org/wiki/Kisatchie_National_Forest"
    name: "Kisatchie National Forest"
  - url: "https://www.outdoorproject.com/united-states/louisiana/longleaf-scenic-byway"
    name: "Longleaf Scenic Byway"
designations:
  - National Forest Scenic Byway
  - Louisiana State Scenic Byway
states:
  - LA
ll:
  - -93.193153
  - 31.489691000000107
bounds:
  - - -93.193153
    - 31.45694000000009
  - - -92.96180699999996
    - 31.516010000000108

---

Located south of the Natchitoches, the 17-mile Longleaf Trail Scenic Byway guides motorists through the most unique scenery in the Kisatchie National Forest, offering natural beauty as well as direct and indirect access to several popular recreation spots in the Kisatchie Hills area.

The byway traverses the Kisatchie Ranger District, the most scenic and enticing area within the 600,000 acre Kisatchie National Forest.  It also crosses the Kisatchie Bayou, a scenic stream flowing through the district from south to north into Old River. Backpackers and hikers can explore the 8,700-acre Kisatchie Hills Wilderness and its Backbone Trail. In addition, horse riders will enjoy the Caroline Dormon Hiking and Equestrian Trail. Deer, Turkey, songbirds and other wildlife can be also viewed throughout the district.

Some "must see" sites are Kisatchie Bayou Recreation Area and Longleaf Vista, where hikers and picnickers enjoy spectacular scenery. An abundance of wildflowers, scenic views, thriving hardwood and pine forests, historic points, and unusual rock formations inspire visitors to return often.
